from .color import Color, Colour
from .conversion import convert
from .mixing import mix, brightness
from . import presets
from .picker import pick_raw

__title__ = 'color_palette'
__author__ = 'SnowballSH, 12944qwerty, one-wq'
__license__ = 'MIT'
__version__ = '0.2.5'
